# xmonkey-namonica

## Supported Formats:
xmonkey-namonica "pkg:nuget/newtonsoft.json@13.0.1/" --full
xmonkey-namonica "pkg:pypi/flask@3.0.3/" --full
xmonkey-namonica "pkg:npm/tslib@2.6.2/" --full
xmonkey-namonica "pkg:generic/openssl@1.1.10g?download_url=https://openssl.org/source/openssl-1.1.0g.tar.gz&checksum=sha256:de4d501267da" --full
xmonkey-namonica "pkg:generic/bitwarderl?vcs_url=git%2Bhttps://git.fsfe.org/dxtr/bitwarderl%40cc55108da32" --full
xmonkey-namonica "pkg:github/package-url/purl-spec@b33dda1cf4515efa8eabbbe8e9b140950805f845" --full